Reference in-memory implementation of soaprs ports.
Structs
- Memory
Event Bus - Subscription-order event bus for tests and single-process applications.
- Memory
Event Outbox - In-memory event store and outbox sharing one atomic commit boundary.
- Memory
Event Store - Append-only in-memory event store with optimistic concurrency checks.
- Memory
Inbox Store - In-memory idempotency records scoped by consumer name.
- Memory
Outbox Store - In-memory outbox with exclusive, expiring worker claims.
- Memory
Projection Checkpoint Store - In-memory monotonically advancing projection checkpoints.
- Memory
Repository - Thread-safe in-memory repository used as a reference adapter.
- Memory
Saga Action Store - In-memory durable saga action and timer store.
- Memory
Saga Outbox - In-memory saga state and action outbox sharing one atomic commit boundary.
- Memory
Saga Store - In-memory application-defined saga state.
- Memory
Snapshot Store - In-memory latest-snapshot persistence.
- Memory
Stored Event Store - Append-only in-memory persistence for serialized event payloads.
- Memory
Transactional Projection - In-memory reference projection with an atomic read-model/checkpoint boundary.
- Subscription
Id - Opaque identity of an in-memory event subscription.
Traits
- Queryable
- Provides logical field values to the in-memory query evaluator.