pub struct MemoryEventOutbox<E, M> { /* private fields */ }Expand description
In-memory event store and outbox sharing one atomic commit boundary.
Implementations
Sourceimpl<E, M> MemoryEventOutbox<E, M>
impl<E, M> MemoryEventOutbox<E, M>
Sourcepub const fn event_store(&self) -> &MemoryEventStore<E>
pub const fn event_store(&self) -> &MemoryEventStore<E>
Returns the event-store view used to read committed events.
Sourcepub const fn outbox(&self) -> &MemoryOutboxStore<M>
pub const fn outbox(&self) -> &MemoryOutboxStore<M>
Returns the outbox view used by a publisher worker.